{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "label": "sequence names to retrieve, one per line",
                    "streamable": true,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "sequences",
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "sequences"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "streamable": true,
                    "id": "#extract_coord_lines.cwl/summary"
                }
            ],
            "baseCommand": [
                "grep",
                "-v",
                "^#"
            ],
            "successCodes": [
                0,
                1
            ],
            "stdout": "coord_lines",
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract_coord_lines.cwl/coord_lines",
                    "outputBinding": {
                        "glob": "coord_lines"
                    }
                }
            ],
            "id": "#extract_coord_lines.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search profile(s) against a sequence database",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005305"
                            ],
                            "version": [
                                "3.1b2"
                            ],
                            "package": "hmmer"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "report sequences >= this bit score threshold in output",
                    "inputBinding": {
                        "prefix": "-T"
                    },
                    "id": "#nhmmer.cwl/bitscore_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1370",
                    "id": "#nhmmer.cwl/query"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#nhmmer.cwl/sequences"
                }
            ],
            "baseCommand": [
                "nhmmer"
            ],
            "arguments": [
                "--tblout",
                "per_target_summary.txt",
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "per_target_summary.txt"
                    },
                    "id": "#nhmmer.cwl/per_target_summary"
                }
            ],
            "id": "#nhmmer.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#main/indexed_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "label": "tRNA model to search with",
                    "id": "#main/model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/nhmmer/per_target_summary",
                    "id": "#main/hmmer_search_results"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#main/fetch_aligned_sequences/sequences",
                    "id": "#main/matching_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#main/nhmmer/per_target_summary",
                            "id": "#main/extract_coord_lines/summary"
                        }
                    ],
                    "out": [
                        "#main/extract_coord_lines/coord_lines"
                    ],
                    "id": "#main/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#main/extract_coordinates/extract_coordinates",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "streamable": true,
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n(7) alifrom: The position in the target sequence at which the hit\n             starts\n(8) ali to: The position in the target sequence at which the hit\n            ends.\n",
                                "id": "#main/extract_coordinates/extract_coordinates/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1, $7, $8, $1}"
                        ],
                        "stdout": "formatted_names_and_coords",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#main/extract_coordinates/extract_coordinates/formatted_names_and_coords",
                                "outputBinding": {
                                    "glob": "formatted_names_and_coords"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#main/extract_coord_lines/coord_lines",
                            "id": "#main/extract_coordinates/coordinate_lines"
                        }
                    ],
                    "out": [
                        "#main/extract_coordinates/formatted_names_and_coords"
                    ],
                    "id": "#main/extract_coordinates"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#main/indexed_sequences",
                            "id": "#main/fetch_aligned_sequences/indexed_sequences"
                        },
                        {
                            "source": "#main/extract_coordinates/formatted_names_and_coords",
                            "id": "#main/fetch_aligned_sequences/names"
                        },
                        {
                            "default": true,
                            "id": "#main/fetch_aligned_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#main/fetch_aligned_sequences/sequences"
                    ],
                    "id": "#main/fetch_aligned_sequences"
                },
                {
                    "run": "#nhmmer.cwl",
                    "in": [
                        {
                            "default": 40,
                            "id": "#main/nhmmer/bitscore_threshold"
                        },
                        {
                            "source": "#main/model",
                            "id": "#main/nhmmer/query"
                        },
                        {
                            "source": "#main/indexed_sequences",
                            "id": "#main/nhmmer/sequences"
                        }
                    ],
                    "out": [
                        "#main/nhmmer/per_target_summary"
                    ],
                    "id": "#main/nhmmer"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
